"use client";

import { useState, useEffect } from "react";
import { collection, addDoc, updateDoc, deleteDoc, doc, getDocs, getDoc } from "firebase/firestore";
import { db } from "@/lib/firebase";
import { Teacher } from "@/lib/types";
import { useActivity } from "./useActivity";

export const useTeachers = () => {
  const [teachers, setTeachers] = useState<Teacher[]>([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);
  const { addActivity } = useActivity();

  useEffect(() => {
    const fetchTeachers = async () => {
      try {
        const teachersCollection = collection(db, "teachers");
        const teachersSnapshot = await getDocs(teachersCollection);
        const teachersList = teachersSnapshot.docs.map(doc => ({
          id: doc.id,
          ...doc.data()
        })) as Teacher[];
        
        setTeachers(teachersList);
        setLoading(false);
      } catch (err) {
        console.error("Error fetching teachers:", err);
        setError("Failed to fetch teachers");
        setLoading(false);
      }
    };

    fetchTeachers();
  }, []);

  const addTeacher = async (teacher: Omit<Teacher, "id">) => {
    try {
      const docRef = await addDoc(collection(db, "teachers"), teacher);
      const newTeacher = { id: docRef.id, ...teacher };
      setTeachers([...teachers, newTeacher]);

      // Record activity
      await addActivity({
        type: "teacher_added",
        title: "New Teacher Added",
        subject: `${teacher.firstName} ${teacher.lastName}`,
        // details: `Teaching ${teacher.subjects.join(", ")}`,
        entityId: docRef.id,
        date: new Date().toISOString()
      });

      return newTeacher;
    } catch (err) {
      console.error("Error adding teacher:", err);
      setError("Failed to add teacher");
      throw err;
    }
  };

  const updateTeacher = async (id: string, data: Partial<Teacher>) => {
    try {
      const teacherRef = doc(db, "teachers", id);
      const currentTeacher = teachers.find(t => t.id === id);
      await updateDoc(teacherRef, data);

      // Check if status has changed
      if (data.status && currentTeacher && data.status !== currentTeacher.status) {
        await addActivity({
          type: "status_change",
          title: "Teacher Status Updated",
          subject: `${currentTeacher.firstName} ${currentTeacher.lastName}`,
          details: `Status changed from ${currentTeacher.status} to ${data.status}`,
          entityId: id,
          previousStatus: currentTeacher.status,
          date: new Date().toISOString()
        });
      }
      
      setTeachers(teachers.map(teacher => 
        teacher.id === id ? { ...teacher, ...data } : teacher
      ));
      return { id, ...data };
    } catch (err) {
      console.error("Error updating teacher:", err);
      setError("Failed to update teacher");
      throw err;
    }
  };

  const deleteTeacher = async (id: string) => {
    try {
      await deleteDoc(doc(db, "teachers", id));
      setTeachers(teachers.filter(teacher => teacher.id !== id));
    } catch (err) {
      console.error("Error deleting teacher:", err);
      setError("Failed to delete teacher");
      throw err;
    }
  };

  const getTeacherById = async (id: string) => {
    try {
      const teacherDoc = await getDoc(doc(db, "teachers", id));
      if (teacherDoc.exists()) {
        return { id: teacherDoc.id, ...teacherDoc.data() } as Teacher;
      }
      return null;
    } catch (err) {
      console.error("Error getting teacher:", err);
      throw err;
    }
  };

  return {
    teachers,
    loading,
    error,
    addTeacher,
    updateTeacher,
    deleteTeacher,
    getTeacherById,
  };
};